==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/ListServiceFabricApplicableSchedulesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property labName The name of the lab.
 * @property name The name of the service fabric.
 * @property resourceGroupName The name of the resource group.
 * @property userName The name of the user profile.
 */
public data class ListServiceFabricApplicableSchedulesPlainArgs(
    public val labName: String,
    public val name: String,
    public val resourceGroupName: String,
    public val userName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs =
        com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs.builder()
            .labName(labName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .userName(userName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListServiceFabricApplicableSchedulesPlainArgs].
 */
@PulumiTagMarker
public class ListServiceFabricApplicableSchedulesPlainArgsBuilder internal constructor() {
    private var labName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    private var userName: String? = null

    /**
     * @param value The name of the lab.
     */
    @JvmName("cxtsajgqxlahngkp")
    public suspend fun labName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labName = mapped
    }

    /**
     * @param value The name of the service fabric.
     */
    @JvmName("bwfixiyvipbhmvti")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("wltbyfkcssukhrfb")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the user profile.
     */
    @JvmName("johjetgbbhrkvkfa")
    public suspend fun userName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.userName = mapped
    }

    internal fun build(): ListServiceFabricApplicableSchedulesPlainArgs =
        ListServiceFabricApplicableSchedulesPlainArgs(
            labName = labName ?: throw PulumiNullFieldException("labName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            userName = userName ?: throw PulumiNullFieldException("userName"),
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/devtestlab/kotlin/inputs/ListServiceFabricApplicableSchedulesPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.devtestlab.kotlin.inputs

import com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property labName The name of the lab.
 * @property name The name of the service fabric.
 * @property resourceGroupName The name of the resource group.
 * @property userName The name of the user profile.
 */
public data class ListServiceFabricApplicableSchedulesPlainArgs(
    public val labName: String,
    public val name: String,
    public val resourceGroupName: String,
    public val userName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs =
        com.pulumi.azurenative.devtestlab.inputs.ListServiceFabricApplicableSchedulesPlainArgs.builder()
            .labName(labName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .userName(userName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [ListServiceFabricApplicableSchedulesPlainArgs].
 */
@PulumiTagMarker
public class ListServiceFabricApplicableSchedulesPlainArgsBuilder internal constructor() {
    private var labName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    private var userName: String? = null

    /**
     * @param value The name of the lab.
     */
    @JvmName("majqxbypskxfqhqp")
    public suspend fun labName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.labName = mapped
    }

    /**
     * @param value The name of the service fabric.
     */
    @JvmName("wjkjwacmjrjovyvg")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the resource group.
     */
    @JvmName("osopxvsceahblirf")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the user profile.
     */
    @JvmName("yaaufelyojbclqcr")
    public suspend fun userName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.userName = mapped
    }

    internal fun build(): ListServiceFabricApplicableSchedulesPlainArgs =
        ListServiceFabricApplicableSchedulesPlainArgs(
            labName = labName ?: throw PulumiNullFieldException("labName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            userName = userName ?: throw PulumiNullFieldException("userName"),
        )
}
